@@ -5,7 +5,11 @@
 """Discover the package's version number."""
 
 from importlib import metadata
+from typing import Final
 
 
-__version__ = metadata.version(__package__)
+__all__: Final = ["__version__"]
+"""Public module attributes."""
+
+__version__: Final = metadata.version(__package__)
 """The package version number as found by importlib metadata."""
